/*
** defaults.h - all the default values
**
** Keith Zaback (krz@wcug.wwu.edu)
*/

#ifndef INC_DEFAULTS_H
#define INC_DEFAULTS

/* how many read()'s to do during a udp_read() */
#define FURY_UDP_READ_PACK_MAX		4

/* how long to wait for names to resolv (seconds) */
#define FURY_HOST_LOOKUP_WAIT		8

/* how often to run the udp maint */
#define UDP_MAINTENCE_TIME		120

/* max time after a closed event to wait for term acks */
#define FURY_UDP_EXIT_WAIT		10

/* clear req wait for pkt caches */
#define PKTCACHE_CLEAR_REQ_START	8

/* clear req wait for header caches */
#define HDRCACHE_CLEAR_START		15

/* time between sending IP requests for hwaddress */
#define FURY_IP_REQ_TIMEOUT		15
#define FURY_IP_REQ_MAX			4

/* time between sending IP changes for hwaddr (seconds) */
#define FURY_IP_CHANGE_TIMEOUT		15

/* default verbose level */
#define FURY_DEFAULT_VERBOSE_LEVEL	10

/* minimum packet size we should try zlib on */
#define FURY_ZLIB_MIN_SIZE		128

/* time spent waiting in the select() call in ipxfury() (1/10th second) */
#define FURY_WAIT_SECONDS		0
#define FURY_WAIT_USECONDS		100000

/* the amount to add to the "wait" variable each time we get a gen restart */
#define FURY_DIFF_WAIT_ADD		8

/* default number of generations we use a diff before sending a fresh one */
#define FURY_DIFF_GENERATION_MAX	100

/* default min packet size and max wait (# of called to udp_process) */
#define FURY_UDP_BUFFER_THRESHOLD	30
#define FURY_UDP_BUFFER_WAIT_SEC	0
#define FURY_UDP_BUFFER_WAIT_USEC	200000

/* if we haven't received anything in x seconds.. send a keepalive */
#define FURY_UDP_KEEPALIVE_CHECK	600	

/* how long we wait until we send another keepalive (seconds) */
#define FURY_UDP_KEEPALIVE_RESEND	5

/* maximum number of keepalives until we have determined they are gone */
#define FURY_UDP_KEEPALIVE_MAX		3

/* ip addr table */
#define FURY_IPADDR_TABLE_SIZE		11
#define FURY_HWIP_TABLE_SIZE		11
#define FURY_IP_SEND_BUF_SIZE		(4096)

/* event times */
#define DEVICE_STATS_TIME		(5*60)

/* header caching */
#define HDRCACHE_DEFAULT_SIZE		19
#define CACHE_REMOVE_ACCESS_TICKS	6
#define CACHE_REMOVE_STORE_TICKS	2

/* the packet cache hash table size */
#define FURY_PKTCACHE_TABLE_SIZE	19

/* filename defaults */
#define FURY_DEFAULT_CFG_FILENAME	"ipxfury.conf"
#define FURY_DEFAULT_LOGFILENAME	"ipxfury.log"

/* hardware address hash table size */
#define FURY_HWADDR_TABLE_SIZE		19

/* max number of interfaces */
#define FURY_MAX_INTERFACES 		8

/* packet caching info */
#define PKTCACHE_DATA_MAX		(1500-30) /* ipx max data payload */
#define PKTCACHE_MAX_USE_COUNT		10	/* more than 10 times, resend */

/* serial */
#define FURY_SERIAL_RECV_BUF_SIZE	(64*1024)
#define FURY_SERIAL_TRANS_BUF_SIZE	(64*1024)
#define SERIAL_FLUSH_MAX		10

/* ether */
#define FURY_ETHER_RECV_BUF_SIZE	(16*1024)
#define FURY_ETHER_TRANS_BUF_SIZE	(16*1024)
#define ETHER_FLUSH_MAX			20
#define ETHER_FRAMES_READ_MAX		4

/* udp */
#define FURY_UDP_RECV_BUF_SIZE		(16*1024)
#define FURY_UDP_TRANS_BUF_SIZE		(4*1024)	/* only holds pointers */

/* ipxfury */
#define FURY_COMMAND_BUF_SIZE		80
#define CACHE_MAINTENCE_TIME		120


#endif
