/*
** term.c - the mini termial-like program
**
** Keith Zaback (krz@wcug.wwu.edu) Apr 98
*/

/* includes */
#include "ipxfury.h"
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <termios.h>
#include <sys/types.h>
#include <sys/time.h>

/* protos */
void			fury_term_main(int ser_fd, int tty_fd);

/* extern */
extern GLOBALS	ifg;


/*
**	FURY_TERM()
*/
void fury_term(char *args)
{
	struct termios		tio, tiosave;
	int			tty;
	INTERFACE		*iface;
	int			i;

#ifdef CURSES_CONSOLE
	/* can't do this yet! */
	errormsg(0, "fury_term", "no term inside of the curses console yet!");
	return;
#endif
	
	/* are there any args? */
	if( args == NULL ) {
		/* locate the 1st serial device */
		iface = NULL;
		for( i = 0; i < ifg.total_interfaces; i++ ) {
			if( ifg.interfaces[i].type == FURY_IF_TYPE_SERIAL ) {
				iface = &ifg.interfaces[i];
				break;
			}
		}
		/* did we get one? */
		if( iface == NULL ) {
			errormsg(0, "fury_term", "could not locate a serial interface");
			return;
		}
	} else {
		/* locate the one they want */
		iface = interface_find_name(args);	
		
		/* did we get it? */
		if( iface == NULL ) {
			errormsg(0, "fury_term", "could not find interface '%s'", args);
			return;
		}
	}
	
	/* let them know what interface we are using */
	notice("Using interface '%s'\n", iface->name);	
	

	/* open the serial device if it is not already open */
	if( (iface->flags & FURY_IF_VALID) != FURY_IF_VALID ) {
		if( ! iface->open(iface) )
			return;
	}
	
	/* get our term */
	if( (tty = open("/dev/tty", O_RDWR)) < 0 ) {
		errormsg(0, "fury_term", "could not open /dev/tty");
		return;
	}
	
	/* now get its attributes */
	if( tcgetattr(tty, &tio) < 0 ) {
		errormsg(0, "fury_term", "could not get terminal attributes");
		return;
	}
	
	/* make a copy so we can restore it */
	memcpy(&tiosave, &tio, sizeof(tio));
	
	/* put the terminal into raw mode */
	cfmakeraw(&tio);
	
	/* set the new attributes */
	if( tcsetattr(tty, TCSANOW, &tio) < 0 ) {
		errormsg(0, "fury_term", "failed to change terminal settings");
		return;
	}
	
	/* ok, terminal is now in raw mode */
		
	notice("((( Fury Term [^D to exit] )))\r\n");
	
	/* call the main fury term */
	fury_term_main(iface->fd, tty);
	
	/* restore terminal */
	tcsetattr(tty, TCSANOW, &tiosave);
	
	/* close file des - we won't lose the terminal since we still have it open */
	close(tty);

	/* final cleanup */
	notice("\n");

	/* done */
	return;

}



/*
**	FURY_TERM_MAIN() - cheesy "term" to allow you to dial or answer
*/
void fury_term_main(int ser_fd, int tty_fd)
{
	int		done;
	fd_set		readfds;
	char		ch, serbuf[256];
	int		n;
	
	/* not done */
	done = 0;
	
	/* the main loop */
	while( !done ) {
		FD_ZERO(&readfds);
		FD_SET(tty_fd, &readfds);
		FD_SET(ser_fd, &readfds);
		
		/* wait for data */
		if( select(FD_SETSIZE, &readfds, NULL, NULL, NULL) > 0 ) {
			/* does the terminal have something to read? */
			if( FD_ISSET(tty_fd, &readfds) ) {
				if( read(tty_fd, &ch, 1) == 1 ) {
					if( ch == 0x04 ) {	/* ^D - stop */
						done = 1;
					} else if( ch == 0x02 ) {	/* ^B - break */
						notice("Sending break...");
						tcsendbreak(ser_fd, 1);
						notice("\r\n");
					} else {
						if( (ch == '\r') || (ch == '\n') ) 
							write(tty_fd, "\r\n", 2);
						write(ser_fd, &ch, 1);
					}
				}
			}
			
			/* does the modem have something for us */
			if( FD_ISSET(ser_fd, &readfds) ) {
				n = read(ser_fd, serbuf, 256);
				if( n > 0 ) 
					write(tty_fd, serbuf, n);
			}
		} else {
			notice("select() error\r\n");
			done = 1;
		}
	
	} /* while */
	

}

